@@ -31,7 +31,7 @@ use POSIX qw(locale_h);
 setlocale(LC_NUMERIC,"C");
 
 
-$VERSION = '8.6';
+$VERSION = '8.7';
 
 # Cost scores used when converting PLSQL to PLPGSQL
 my %size_score = (
@@ -103,6 +103,8 @@ sub plsql_to_plpgsql
 	# Change SYSDATE to 'now' or current timestamp.
 	$str =~ s/SYSDATE[\s\t]*\([\s\t]*\)/LOCALTIMESTAMP/igs;
 	$str =~ s/SYSDATE/LOCALTIMESTAMP/igs;
+	# Replace sysdate +/- N by localtimestamp - 1 day intervel
+	#$str =~ s/LOCALTIMESTAMP([\s\t]*\-|\+[\s\t]*)(\d+)[\s\t]*,/LOCALTIMESTAMP$1'$2 day'\:\:interval,/igs;
 	# remove FROM DUAL
 	$str =~ s/FROM DUAL//igs;
 	# Remove leading : on Oracle variable
@@ -190,11 +192,11 @@ sub plsql_to_plpgsql
 	$str =~ s/FOR(.*?)IN[\s\t]+REVERSE[\s\t]+([^\.\s\t]+)[\s\t]*\.\.[\s\t]*([^\s\t]+)/FOR$1IN REVERSE $3..$2/isg;
 
 	# Replace exit at end of cursor
-	$str =~ s/EXIT WHEN [^\%]+\%NOTFOUND[\s\t]*;/IF NOT FOUND THEN EXIT; END IF;/isg;
-	$str =~ s/EXIT WHEN \([\s\t]*[^\%]+\%NOTFOUND[\s\t]*\)[\s\t]*;/IF NOT FOUND THEN EXIT; END IF;/isg;
+	$str =~ s/EXIT WHEN ([^\%]+)\%NOTFOUND[\s\t]*;/IF NOT FOUND THEN EXIT; END IF; -- apply on $1/isg;
+	$str =~ s/EXIT WHEN \([\s\t]*([^\%]+)\%NOTFOUND[\s\t]*\)[\s\t]*;/IF NOT FOUND THEN EXIT; END IF; -- apply on $1/isg;
 	# Same but with additional conditions
-	$str =~ s/EXIT WHEN [^\%]+\%NOTFOUND[\s\t]+([;]+);/IF NOT FOUND $1 THEN EXIT; END IF;/isg;
-	$str =~ s/EXIT WHEN \([\s\t]*[^\%]+\%NOTFOUND[\s\t]+([\)]+)\)[\s\t]*;/IF NOT FOUND $1 THEN EXIT; END IF;/isg;
+	$str =~ s/EXIT WHEN ([^\%]+)\%NOTFOUND[\s\t]+([;]+);/IF NOT FOUND $2 THEN EXIT; END IF; -- apply on $1/isg;
+	$str =~ s/EXIT WHEN \([\s\t]*([^\%]+)\%NOTFOUND[\s\t]+([\)]+)\)[\s\t]*;/IF NOT FOUND $2 THEN EXIT; END IF; -- apply on $1/isg;
 	# Replacle call to SQL%NOTFOUND
 	$str =~ s/SQL\%NOTFOUND/NOT FOUND/isg;
 
